function [muX, muY, betaX, betaY] = CalcFodoPhaseAdvAndWriteToMadx(IF, ID, betaX, alphaX, betaY, alphaY, E, I820, I840)
% [muX, muY, betaX, betaY] = FodoTwissFromI(IF, ID, betaX, alphaX, betaY, alphaY)
% -------------------------------------------------
% Takes the two currents IF and ID as parameters, which are the currents of
% the focusing and defocusing quads of the FODO structure. Outputs the phase
% advance in X and Y, and the beta value in X and Y, at the start of the
% FODO structure.
% Also takes the twiss parameters in each plane as parameters for output to
% madx.

%% Parameters
% Currents
IQFR0200 = IF;
IQDR0240 = ID;
 
% From madx 
CLIGHT	= 299792458;
LQLX	= 0.186;
ECQDX	= 0.873;	% excitation constant dB/dx/I = 0.873 T/Am
FQDX	= CLIGHT * 1E-6 * ECQDX;        % for TBL
P08     = sqrt(E^2 - 0.510998902^2);	% momentum
KQFR0200	= -FQDX * IQFR0200 / P08;
KQDR0240    = -FQDX * IQDR0240 / P08;

l = LQLX;           % [m]
L_FODO = 2.82002;	% [m]

k1 =  abs(KQFR0200);
k2 =  abs(KQDR0240);

OO = zeros(2,2);

%% Make transport matrices
% Defocusing quad
k = abs(k2);
phi = l*sqrt(k);
M_F = [cos(phi)             (1/sqrt(k))*sin(phi)
       -sqrt(k)*sin(phi)    cos(phi)];
M_D = [cosh(phi)             (1/sqrt(k))*sinh(phi)
       sqrt(k)*sinh(phi)    cosh(phi)];
M4_D = [M_D OO; OO M_F];

% Half of a focusing quad
k = abs(k1);
phi05 = l*sqrt(k)/2;
M_F05 = [cos(phi05)             (1/sqrt(k))*sin(phi05)
       -sqrt(k)*sin(phi05)    cos(phi05)];
M_D05 = [cosh(phi05)             (1/sqrt(k))*sinh(phi05)
       sqrt(k)*sinh(phi05)    cosh(phi05)];
M4_F05 = [M_F05 OO; OO M_D05];

% Drift section
d = L_FODO/2 - l;
M_0 = [1 d; 0 1];
M4_0 = [M_0 OO; OO M_0];

% Combine everything to a FODO structure
M4 = M4_F05*M4_0*M4_D*M4_0*M4_F05;

%% Get parameters for each plane
% Horizontal: Phase advance and beta
M = M4(1:2,1:2);

cos1 = 0.5*trace(M);
mu_thick = acos(cos1);
muX = (180/pi)*mu_thick;
betaXPeriodic = M(1,2) / sin(mu_thick);

% Vertical: : Phase advance and beta
M = M4(3:4,3:4);

cos1 = 0.5*trace(M);
mu_thick = acos(cos1);
muY = (180/pi)*mu_thick;
betaYPeriodic = M(1,2) / sin(mu_thick);

%% Output currents, periodic betas and initial twiss params in a file in mad-x format
fid = fopen('madx_input_parameters', 'w');
fprintf(fid, 'IQFR0200 := %5.5f;\n', IQFR0200);
fprintf(fid, 'IQDR0240 := %5.5f;\n', IQDR0240);
fprintf(fid, 'BETXPERIODIC := %5.5f;\n', betaXPeriodic);
fprintf(fid, 'BETYPERIODIC := %5.5f;\n', betaYPeriodic);
fprintf(fid, 'BET0X := %5.5f;\n', betaX);
fprintf(fid, 'ALF0X := %5.5f;\n', alphaX);
fprintf(fid, 'BET0Y := %5.5f;\n', betaY);
fprintf(fid, 'ALF0Y := %5.5f;\n', alphaY);
fprintf(fid, 'E8 := %5.5f;\n', E);
fprintf(fid, 'IQTL2a := %5.5f;\n', I820);
fprintf(fid, 'IQTL2b := %5.5f;\n', I840);
fprintf(fid, 'return;');
fclose(fid);