function DrawLattice(handles, pos_qf, pos_qd, pos_bpm, pos_mtv, ...
    pos_cor, pos_bend, pos_pets, l_tbl, pos_zero)
% Drawlattice(handles, pos_qf, pos_qd, pos_bpm, pos_mtv, pos_cor, pos_bend,
%             pos_pets, l_tbl)
% ------------------------------------------------------------
% Draws a graph of an accelerator lattice with focusing and defocusing
% quads, BPMs, and a spectromenter.
% pos_qf:        A matrix where the first row indicates all focusing quad
%                positions (in the middle), and the second row indicates
%                their lengths.
% pos_qd:        A matrix where the first row indicates all defocusing quad
%                positions (in the middle), and the second row indicates
%                their lengths.
% pos_bpm:       A matrix where the first row indicates all BPM positions (in
%                the middle), and the second row indicates their lengths.
% pos_mtv:       A matrix where the first row indicates all emittance
%                screen positions (in the middle), and the second row
%                indicates their lengths.
% pos_cor:       A matrix where the first row indicates all corrector
%                magnet positions (in the middle), and the second row
%                indicates their lengths.
% pos_bend:      A matrix where the first row indicates all dipole
%                positions (in the middle), and the second row indicates
%                their lengths.
% pos_pets:      A matrix where the first row indicates all PETS positions
%                (in the middle), and the second row indicates their
%                lengths.
% l_tbl:         A scalar containing the total length of the lattice.
% pos_zero:      A scalar containing the 'zero position' of the lattice

axes(handles.axLattice)
symbol_scaling = 0.25; % For setting a size of the symbols
hold on;

% Draw a black particle path
plot([0 pos_bend(1,2) l_tbl], [0 0 -symbol_scaling], 'Color', 'k');

% Draw a small arrow for the spectrometer at the beginning
arrowEnd = pos_qf(1,3) - (pos_qf(1,3) - pos_bend(1,1)) * 0.35;
plot([pos_bend(1,1) arrowEnd arrowEnd-0.35 arrowEnd arrowEnd], ...
     [0 symbol_scaling symbol_scaling symbol_scaling symbol_scaling*0.6], 'k');

% Draw a small arrowhead for the dump
plot([l_tbl-0.35, l_tbl, l_tbl], ...
     [-symbol_scaling, -symbol_scaling, -symbol_scaling*0.6], 'k');

%% Draw all focusing quads
for i = 1:size(pos_qf, 2)
    [PosZ, PosY] = ShapeQF(pos_qf(1,i), pos_qf(2,i), symbol_scaling);
    fill(PosZ, PosY, [0.2 0.2 1.0]);
end

%% Draw all defocusing quads
for i = 1:size(pos_qd, 2)
    [PosZ, PosY] = ShapeQD(pos_qd(1,i), pos_qd(2,i), symbol_scaling);
    fill(PosZ, PosY, [1.0 0.1 0.1]);
end

%% Draw all BPMs
for i = 1:size(pos_bpm, 2)
    [PosZ, PosY] = ShapeBpm(pos_bpm(1,i), pos_bpm(2,i), symbol_scaling);
    fill(PosZ, PosY, [0.2 0.9 0.2]);
end

%% Draw all MTVs
for i = 1:size(pos_mtv, 2)
    [PosZ, PosY] = ShapeMtv(pos_mtv(1,i), pos_mtv(2,i), symbol_scaling);
    fill(PosZ, PosY, [1.0 1.0 0.3]);
end

%% Draw corrector magnets
for i = 1:size(pos_cor, 2)
    [PosZ1, PosY1, PosZ2, PosY2] = ShapeCor(pos_cor(1,i), ...
        pos_cor(2,i), symbol_scaling);
    fill(PosZ1, PosY1, [0.65 0.32 0.07]);
    fill(PosZ2, PosY2, [0.65 0.32 0.07]);
end

%% Draw the dipoles
for i = 1:size(pos_bend, 2)
    [PosZ, PosY] = ShapeBend(pos_bend(1,i), pos_bend(2,i), symbol_scaling);
    fill(PosZ, PosY, [0.65 0.32 0.07]);
end

%% Draw the PETS
for i = 1:size(pos_pets, 2)
    [PosZ, PosY] = ShapePets(pos_pets(1,i), pos_pets(2,i), symbol_scaling);
    fill(PosZ, PosY, [1.0 0.7 0.3]);
    text(pos_pets(1,i), 0, '\fontsize{8}P', 'HorizontalAlignment', 'center');
end

%% Draw a line at the zero position of the lattice
plot([pos_zero, pos_zero], [-symbol_scaling, symbol_scaling], 'k:');

%% Set plot parameters
hold off;
axis([0, l_tbl, -symbol_scaling*1.2 symbol_scaling*1.2]);
set(gca, 'YTickLabelMode', 'Manual', 'YTick', [], ...
    'XTickLabelMode', 'Manual', 'XTick', [])
axis off;

%% Set some current values for now
% TODO: Get real values
set(handles.edtCurrent1, 'String', '1.6');
set(handles.edtCurrent2, 'String', '10.6');
set(handles.edtCurrent3, 'String', '1.0');
set(handles.edtCurrent4, 'String', '1.0');
set(handles.edtCurrent5, 'String', '5.0');
set(handles.edtCurrent6, 'String', '5.0');