function [pos_qf, pos_qd, pos_bpm, pos_mtv, pos_cor, pos_bend, pos_pets, l_end, pos_zero] ...
    = LatticeFromMadx()
% Reads the madx output and outputs the positions and lengths of quads,
% bpms, emittance screens, correctors, dipoles, pets. Also outputs the
% total length of the lattice and the defined zero position
% -------------------------------------
% pos_qf:   Positions of F quads in 1st row, lengths in the 2nd row
% pos_qd:	Lengths of D quads in the 1st row, lengths in the 2nd row
% pos_bpm:	Positions of the BPMs in the 1st row, lengths in the 2nd row
% pos_mtv:	Positions of MTVs in the 1st row, lengths in the 2nd row
% pos_cor:	Positions of correctors in the 1st row, lenghts in the 2nd row
% pos_bend:	Positions of dipoles in the 1st row, lengths in the 2nd row
% pos_pets:	Positions of PETS in the 1st row, lengths in the 2nd row
% l_end:	Total length of the lattice
% pos_zero:	Defined zero position of the lattice, near the CLEX wall

%% Read mad-x survey file
fid = fopen('madx_output_twiss');
C = textscan(fid, '%q %f %f %*[^\n]', 'Headerlines', 47);
names = C{:,1};
pos = C{:,2};
lengths = C{:,3};
fclose(fid);

%% Find positions and lengths of the different elements
% Find indexes
i_f = []; i_d = []; i_b = []; i_e = []; i_c = []; i_s = []; i_p = [];
for i = 1:size(names,1)
    name = char(names(i));
    if (name(3) == '.' && name(4) == 'Q' && name(5) == 'F')
        i_f = [i_f i];  %#ok<AGROW> % Focusing quad (horizontally)
    elseif (name(3) == '.' && name(4) == 'Q' && name(5) == 'D')
        i_d = [i_d i];  %#ok<AGROW> % Defocusing quads (horizontally)
    elseif (name(3) == '.' && name(4) == 'B' && name(5) == 'P' && (name(6) == 'M' || name(6) == 'S'))
        i_b = [i_b i];  %#ok<AGROW> % BPMs
    elseif ((name(3) == '.' && name(4) == 'M' && name(5) == 'T' && name(6) == 'V') || ...
        (name(4) == '.' && name(5) == 'M' && name(6) == 'T' && name(7) == 'V'))
        i_e = [i_e i];  %#ok<AGROW> % Emittance screens
    elseif (name(3) == '.' && name(4) == 'D' && name(5) == 'H' && name(6) == 'D')
        i_c = [i_c i];  %#ok<AGROW> % Corrector magnets
    elseif (name(3) == '.' && name(4) == 'B' && name(5) == 'H' && name(6) == 'L')
        i_s = [i_s i];  %#ok<AGROW> % Dipoles
    elseif (name(3) == '.' && name(4) == 'P' && name(5) == 'E' && name(6) == 'T')
        i_p = [i_p i];  %#ok<AGROW> % PETS
    end
end

%% Find positions and lengths of all elements
pos_qf = [pos(i_f)'-lengths(i_f)'/2;    lengths(i_f)'];	% Focusing quads (horizontally)
pos_qd = [pos(i_d)'-lengths(i_d)'/2;    lengths(i_d)']; % Defocusing quads (horizontally)
pos_bpm = [pos(i_b)'-lengths(i_b)'/2;   lengths(i_b)']; % BPMs
pos_mtv = [pos(i_e)'-lengths(i_e)'/2;   lengths(i_e)']; % Emittance screens
pos_cor = [pos(i_c)'-lengths(i_c)'/2;   lengths(i_c)']; % Corrector magnets
pos_bend = [pos(i_s)'-lengths(i_s)'/2;  lengths(i_s)']; % Dipoles
pos_pets = [pos(i_p)'-lengths(i_p)'/2;  lengths(i_p)']; % PETS

%% Find the total length of the lattice
l_end = pos(size(pos,1));

%% Find position of the 'zero position' near the wall
pos_zero = 0;
for i = 1:size(names,1)
    name = char(names(i));
    if strcmp(name,'ZEROPOS')
        pos_zero = pos(i);
        break;
    end
end