function [betaX, alphaX, betaY, alphaY] = ...
    TransportTwiss_ToPets(I3, I4, I5, I6, I7, beta0x, alpha0x, beta0y, alpha0y, E)
% Transports the twiss parameters from the quad scan to the PETS

%% Constants
c       = 299792458;
p       = sqrt(E^2 - 0.510998902^2);	% Momentum [MeV/c]

% TSL Celsius quad
LQLS	= 0.295;                % length of QL TSL
ECQDS	= 0.106;                % excitation constant dB/dx/I [T/Am]
FQDS    = c * 1e-6 * ECQDS;     % for TSL

isquadzero = 0;
IQFL0910 = I3;
IQDL0920 = I4;
if IQFL0910 == 0
    IQFL0910 = 1e-8;
    isquadzero = 1;
end
if IQDL0920 == 0
    IQDL0920 = 1e-8;
    isquadzero = 1;
end
KQFL	=  FQDS * IQFL0910 / p;
% KQDL	= -FQDS * IQDL0920 / p;

% LURE round quad
LQLM	= 0.300;                % length of aircooled quad
ECQDL4	= 0.335;                % excitation constant dB/dx/I [T/Am]
FQDL4	= c * 1e-6 * ECQDL4; 

IQFM0110 = I5;
IQDM0120 = I6;
if IQFM0110 == 0
    IQFM0110 = 1e-8;
    isquadzero = 1;
end
if IQDM0120 == 0
    IQDM0120 = 1e-8;
    isquadzero = 1;
end
KQFM	=  FQDL4 * IQFM0110 / p;
% KQDM	= -FQDL4 * IQDM0120 / p;

% TBL quad
LQLX    = 0.186;
ECQDX   = 0.873;
FQDX    = c * 1e-6 * ECQDX;

IQFR0200 = I7;
if IQFR0200 == 0
    IQFR0200 = 1e-8;
    isquadzero = 1;
end
KQFR    = FQDX * IQFR0200 / p;

if isquadzero
    disp('Warning: One or more quadrupoles had 0 current. Setting to 1e-8 for calculation.');
end

%% Matrix elements
OO = zeros(2,2);

% Thick lens TSL
k = abs(KQFL);
phi = LQLS * sqrt(k);
M_F = [cos(phi)             (1/sqrt(k))*sin(phi)
       -sqrt(k)*sin(phi)    cos(phi)];
M_D = [cosh(phi)             (1/sqrt(k))*sinh(phi)
       sqrt(k)*sinh(phi)    cosh(phi)];
M4L_D = [M_D OO; OO M_F];   % Focusing quad (madx)
M4L_F = [M_F OO; OO M_D];   % Defocusing quad (madx)

% Thick lens LURE
k = abs(KQFM);
phi = LQLM * sqrt(k);
M_F = [cos(phi)             (1/sqrt(k))*sin(phi)
       -sqrt(k)*sin(phi)    cos(phi)];
M_D = [cosh(phi)             (1/sqrt(k))*sinh(phi)
       sqrt(k)*sinh(phi)    cosh(phi)];
M4M_D = [M_D OO; OO M_F];   % Focusing quad (madx)
M4M_F = [M_F OO; OO M_D];   % Defocusing quad (madx)

% Thick lens TBL
k = abs(KQFR);
phi = LQLX * sqrt(k);
M_F = [cos(phi)             (1/sqrt(k))*sin(phi)
       -sqrt(k)*sin(phi)    cos(phi)];
M_D = [cosh(phi)             (1/sqrt(k))*sinh(phi)
       sqrt(k)*sinh(phi)    cosh(phi)];
M4R_D = [M_D OO; OO M_F];   % Focusing quad (madx)
M4R_F = [M_F OO; OO M_D];   % Defocusing quad (madx)

% Drift spaces. Kickers and dipoles treated as drifts everywhere
d = 0.137 + 0.126 + 0.137;
M_0 = [1 d; 0 1];
M4_D01 = [M_0 OO; OO M_0];

d = 0.086 + 0.126 + 0.178 + 0.240 + 0.970 + 0.25 + 0.450 + 1.41;
M_0 = [1 d; 0 1];
M4_D02 = [M_0 OO; OO M_0];

d = 0.2;
M_0 = [1 d; 0 1];
M4_D03 = [M_0 OO; OO M_0];

d = 0.11 + 0.240 + 0.96 + 0.240 + 0.007 + 0.126 + 0.2205 + 0.032;
M_0 = [1 d; 0 1];
M4_D04 = [M_0 OO; OO M_0];

d = 0.054 + 0.126 + 0.022;
M_0 = [1 d; 0 1];
M4_D05 = [M_0 OO; OO M_0];

% Total matrix
% M4 = M4_D05 * M4R_D * M4_D04 * M4M_F * M4_D03 * M4M_D * M4_D02 * M4L_F * M4_D01 * M4L_D;

% Alternative (because of madx convention)
M4 = M4_D05 * M4R_F * M4_D04 * M4M_D * M4_D03 * M4M_F * M4_D02 * M4L_D * M4_D01 * M4L_F;

%% Transport Twiss parameters
B0x = [beta0x   -alpha0x;   -alpha0x   (1+alpha0x^2)/beta0x];
B0y = [beta0y   -alpha0y;   -alpha0y   (1+alpha0y^2)/beta0y];

B0 = [B0x  OO;  OO  B0y];
B1 = M4 * B0 * M4';

betaX = B1(1,1);
alphaX = -B1(1,2);
betaY = B1(3,3);
alphaY = -B1(3,4);